[llvm-commits] CVS: llvm/include/llvm/Analysis/Dominators.h

Devang Patel dpatel at apple.com
Mon Jun 4 09:43:47 PDT 2007



Changes in directory llvm/include/llvm/Analysis:

Dominators.h updated: 1.86 -> 1.87
---
Log message:

s/DominatorTree::createNewNode/DominatorTree::addNewBlock/g


---
Diffs of the changes:  (+6 -7)

 Dominators.h |   13 ++++++-------
 1 files changed, 6 insertions(+), 7 deletions(-)


Index: llvm/include/llvm/Analysis/Dominators.h
diff -u llvm/include/llvm/Analysis/Dominators.h:1.86 llvm/include/llvm/Analysis/Dominators.h:1.87
--- llvm/include/llvm/Analysis/Dominators.h:1.86	Mon Jun  4 11:22:33 2007
+++ llvm/include/llvm/Analysis/Dominators.h	Mon Jun  4 11:43:25 2007
@@ -170,18 +170,17 @@
   // API to update (Post)DominatorTree information based on modifications to
   // the CFG...
 
-  /// createNewNode - Add a new node to the dominator tree information.  This
-  /// creates a new node as a child of IDomNode, linking it into the children
-  /// list of the immediate dominator.
-  ///
-  DomTreeNode *createNewNode(BasicBlock *BB, DomTreeNode *IDomNode) {
+  /// addNewBlock - Add a new node to the dominator tree information.  This
+  /// creates a new node as a child of DomBB dominator node,linking it into 
+  /// the children list of the immediate dominator.
+  DomTreeNode *addNewBlock(BasicBlock *BB, DomTreeNode *IDomNode) {
     assert(getNode(BB) == 0 && "Block already in dominator tree!");
     assert(IDomNode && "Not immediate dominator specified for block!");
     return DomTreeNodes[BB] = IDomNode->addChild(new DomTreeNode(BB, IDomNode));
   }
 
-  void createNewNode(BasicBlock *BB, BasicBlock *DomBB) {
-    createNewNode(BB, getNode(DomBB));
+  DomTreeNode *addNewBlock(BasicBlock *BB, BasicBlock *DomBB) {
+    return addNewBlock(BB, getNode(DomBB));
   }
 
   /// changeImmediateDominator - This method is used to update the dominator






More information about the llvm-commits mailing list